import type { Metadata } from "next";
import "@fontsource-variable/kode-mono";
import "./globals.css";
import { Footer } from "@/components/footer";
import { Header } from "@/components/header";
import { PrimaryNavigationMenu } from "@/components/primary-nav";
import { Providers } from "@/components/providers/providers";
import { ThemeProvider } from "@/components/providers/theme-provider";
import { Toaster } from "@/components/ui/toaster";
import type React from "react";
import Link from "next/link";
import {Button} from "@/components/ui/button";

export const metadata: Metadata = {
	title: "YeloBit",
	description: "Generated by create next app",
	icons: "yellow-bit.svg",
};

export default function RootLayout({
	children,
}: Readonly<{
	children: React.ReactNode;
}>) {
	return (
		<html lang="en">
			<head>
				<link rel="icon" href="/favicon.ico" sizes="any" />
			</head>
			<body className={"w-full min-h-screen flex flex-col items-center justify-between"}>
				<Providers>
					<Header>
						<div className={"flex flex-row flex-wrap md:flex-nowrap gap-2"}>
							<Button asChild variant={'light'}><Link href={'/wallet'}>Wallet</Link></Button>
							<Button asChild variant={'light'}><Link href={'/dashboard'}>Dashboard</Link></Button>
						</div>
					</Header>
					{children}
					<Toaster />
					<Footer />
				</Providers>
			</body>
		</html>
	);
}
