import {type ICryptoInWalletInfo, ITrade, type IUserWalletCryptos} from "@/interfaces/crypto.interface";
import type { IUserData } from "@/interfaces/userdata.interface";

// -----   Request    -----

export interface IApiRegisterReq {
	firstName: string;
	lastName: string;
	pseudo: string;
	city: string;
	email: string;
	password: string;
	age: number;
}

export interface IApiLoginReq {
	email: string;
	password: string;
}

export interface IApiTradeCreateRq {
	id_offer: string;
}

export interface IApiOfferCreateReq {
	id_crypto: string;
	amount: number;
}

export interface IApiCreateReferralCodeReq {
	name: string;
	value: number;
}

export interface IApiDoTradeReq {
	id_offer: string;
}

export interface IApiDoOfferReq {
	id_crypto: string;
	amount: number;
}

// -----   Response   -----

export interface IAbstractApiResponse {
	message?: Array<string> | string;
	error?: string;
	statusCode?: number;
}

export interface IApiRegisterRes extends IAbstractApiResponse {
	access_token?: string;
	user?: IUserData;
}

export interface IApiLoginRes extends IAbstractApiResponse {
	access_token?: string;
}

export interface IApiUserAssetsRes extends IAbstractApiResponse {
	firstName?: string;
	lastName?: string;
	dollarAvailables?: number;
	pseudo?: string;
	UserHasCrypto?: IUserWalletCryptos[];
}

export interface IApiAllTradesRes extends IAbstractApiResponse {}

export interface IAllRankRes extends IAbstractApiResponse {}

export interface IAllReferralCodeRes extends IAbstractApiResponse {}

export interface ICreateReferralCodeRes extends IAbstractApiResponse {}

export interface IReferralCodeUpdateRes extends IAbstractApiResponse {}

export interface IReferralCodeDeleteRes extends IAbstractApiResponse {}

export interface IApiAllOffersRes extends IAbstractApiResponse {
	id: string
	User: {
		pseudo: string
	}
	amount: number
	created_at: string
	id_user: string
	Crypto: ICryptoInWalletInfo
}
